===============================
Next Generation Nexus Generator
===============================


.. image:: https://img.shields.io/pypi/v/nexgen.svg
        :target: https://pypi.python.org/pypi/nexgen
        :alt: PyPI release

.. image:: https://img.shields.io/pypi/pyversions/nexgen.svg
        :target: https://pypi.python.org/pypi/nexgen
        :alt: Supported Python versions

.. image:: https://readthedocs.org/projects/nexgen/badge/?version=latest
        :target: https://nexgen.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://codecov.io/gh/DiamondLightSource/nexgen/graph/badge.svg
 :target: https://codecov.io/gh/DiamondLightSource/nexgen
        :alt: Test coverage

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/ambv/black
        :alt: Code style: black

.. image:: https://zenodo.org/badge/333456026.svg
        :target: https://zenodo.org/badge/latestdoi/333456026


* Free software: BSD license
* Documentation: https://nexgen.readthedocs.io.

This package provides a set of tools to generate NeXus files following the `NXmx <https://manual.nexusformat.org/classes/applications/NXmx.html#nxmx>`_ `Gold Standard <https://journals.iucr.org/m/issues/2020/05/00/ti5018/>`_.

